import { aws_iam as iam, aws_imagebuilder as imagebuilder } from 'aws-cdk-lib';
import { Construct } from 'constructs';
export interface ComponentProps {
    /**
     * Relative path to Image Builder component document
     */
    readonly document: string;
    /**
     * Name of the Component Document
     */
    readonly name: string;
    /**
     * Version for each component document
     */
    readonly version: string;
}
export interface VolumeProps {
    /**
     * Name of the volume
     */
    readonly deviceName: string;
    /**
     * EBS Block Store Parameters
     */
    readonly ebs: imagebuilder.CfnImageRecipe.EbsInstanceBlockDeviceSpecificationProperty;
}
export interface ImagePipelineProps {
    /**
     * List of component props
     */
    readonly components: ComponentProps[];
    /**
     * Name of the instance profile that will be associated with the Instance Configuration.
     */
    readonly profileName: string;
    /**
     * Additional policies to add to the instance profile associated with the Instance Configurations
     */
    readonly additionalPolicies?: iam.ManagedPolicy[];
    /**
     * Name of the Infrastructure Configuration for Image Builder
     */
    readonly infraConfigName: string;
    /**
     * Name of the Image Recipe
     */
    readonly imageRecipe: string;
    /**
     * UserData script that will override default one (if specified)
     *
     * @default - none
     */
    readonly userDataScript?: string;
    /**
     * Image recipe version (Default: 0.0.1)
     */
    readonly imageRecipeVersion?: string;
    /**
     * Name of the Image Pipeline
     */
    readonly pipelineName: string;
    /**
     * The source (parent) image that the image recipe uses as its base environment. The value can be the parent image ARN or an Image Builder AMI ID
     */
    readonly parentImage: string;
    /**
     * KMS Key used to encrypt the SNS topic. Enter an existing KMS Key Alias in your target account/region.
     */
    readonly kmsKeyAlias: string;
    /**
     * List of instance types used in the Instance Configuration (Default: [ 't3.medium', 'm5.large', 'm5.xlarge' ])
     */
    readonly instanceTypes?: string[];
    /**
     * Platform type Linux or Windows (Default: Linux)
     */
    readonly platform?: string;
    /**
     * Email used to receive Image Builder Pipeline Notifications via SNS
     */
    readonly email?: string;
    /**
     * List of security group IDs for the Infrastructure Configuration
     */
    readonly securityGroups?: string[];
    /**
     * Subnet ID for the Infrastructure Configuration
     */
    readonly subnetId?: string;
    /**
     * Configuration for the AMI's EBS volumes
     */
    readonly ebsVolumeConfigurations?: VolumeProps[];
    /**
     * Set to true if you want to enable continuous vulnerability scans through AWS Inpector
     */
    readonly enableVulnScans?: boolean;
    /**
     * Store vulnerability scans through AWS Inpsector in ECR using this repo name (if option is enabled)
     */
    readonly vulnScansRepoName?: string;
    /**
     * Store vulnerability scans through AWS Inpsector in ECR using these image tags (if option is enabled)
     */
    readonly vulnScansRepoTags?: string[];
    /**
     * Set to true if you want to copy this AMI to other accounts using a Distribution Configuration
     */
    readonly enableCrossAccountDistribution?: boolean;
    /**
     * List of accounts to copy this AMI to, if the option to do so is enabled
     */
    readonly distributionAccountIDs?: string[];
    /**
     * List of regions to copy this AMI to, if the option to do so is enabled
     */
    readonly distributionRegions?: string[];
    /**
     * Parameter Store path to store latest AMI ID under
     */
    readonly amiIdSsmPath?: string;
    /**
     * Account ID for Parameter Store path above
     */
    readonly amiIdSsmAccountId?: string;
    /**
     * Region for Parameter Store path above
     */
    readonly amiIdSsmRegion?: string;
}
export declare class ImagePipeline extends Construct {
    imageRecipeComponents: imagebuilder.CfnImageRecipe.ComponentConfigurationProperty[];
    constructor(scope: Construct, id: string, props: ImagePipelineProps);
}
